{% load assignment_request_config %}
{% load i18n %}
<li class="nav-item">
    {% vocabulary "assignment_pl" as v_assignment_pl %}
    <a class="nav-link" href="{% url 'ar-list-assignment-requests' %}">
        {% blocktrans %}Angemeldete {{ v_assignment_pl }}{% endblocktrans %}
    </a>
</li>
