# Generated by Django 3.2.2 on 2021-11-14 17:39

import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('juntagrico', '0034_auto_20210415_2041'),
        ('juntagrico_assignment_request', '0002_fix_naming_and_relation'),
    ]

    operations = [
        migrations.AlterField(
            model_name='assignmentrequest',
            name='activityarea',
            field=models.ForeignKey(blank=True, help_text='Was am besten passt. Ansonsten leer lassen', null=True, on_delete=django.db.models.deletion.SET_NULL, to='juntagrico.activityarea', verbose_name='Tätigkeitsbereich'),
        ),
        migrations.AlterField(
            model_name='assignmentrequest',
            name='amount',
            field=models.PositiveIntegerField(default=1, help_text='Wieviele Arbeitseinsätze?', validators=[django.core.validators.MinValueValidator(1)], verbose_name='Wert'),
        ),
        migrations.AlterField(
            model_name='assignmentrequest',
            name='approver',
            field=models.ForeignKey(blank=True, help_text='An wen soll die Anfrage gesendet werden oder wer hat dich aufgefordert, die Anfrage zu senden?', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='Referenz', to='juntagrico.member', verbose_name='Abgesprochen mit'),
        ),
        migrations.AlterField(
            model_name='assignmentrequest',
            name='description',
            field=models.TextField(default='', help_text='Kurze Beschreibung was du gemacht hat', max_length=1000, verbose_name='Beschreibung'),
        ),
        migrations.AlterField(
            model_name='assignmentrequest',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='assignmentrequest',
            name='location',
            field=models.CharField(blank=True, default='', help_text='Optional', max_length=100, verbose_name='Ort'),
        ),
        migrations.AlterField(
            model_name='assignmentrequest',
            name='member',
            field=models.ForeignKey(help_text='Beantragt von', on_delete=django.db.models.deletion.CASCADE, to='juntagrico.member', verbose_name='Mitglied'),
        ),
        migrations.AlterField(
            model_name='assignmentrequest',
            name='response',
            field=models.TextField(blank=True, help_text='Rückmeldung an Mitglied. Kann leer bleiben.', null=True, verbose_name='Antwort'),
        ),
        migrations.AlterField(
            model_name='assignmentrequest',
            name='response_date',
            field=models.DateField(blank=True, help_text='Typischerweise heute', null=True, verbose_name='Beantwortet am'),
        ),
        migrations.AlterField(
            model_name='assignmentrequest',
            name='status',
            field=models.CharField(choices=[('RE', 'Beantragt'), ('NO', 'Abgelehnt'), ('CO', 'Bestätigt')], default='RE', help_text='Hier "Bestätigt" auswählen, um die Anfrage anzunehmen', max_length=2),
        ),
    ]
